@@ -13,7 +13,7 @@ from cloudbench.api.client import Client
 from cloudbench.api.auth import APIKeyAuth
 from cloudbench.cloud import Cloud
 from cloudbench.fio.config.job import Job
-from cloudbench.fio.config.library import BASE_LINUX_JOB, BASE_FILL_JOB
+from cloudbench.fio.config.library import BASE_LINUX_JOB, BASE_FILL_JOB, BASE_BENCH_JOB
 from cloudbench.fio.engine import FIOEngine
 from cloudbench.fio.report.single import SingleJobReport
 from cloudbench.utils import fs
@@ -34,6 +34,9 @@ DEFAULT_FILE_SIZE = "10G"
 DEFAULT_RAMP_TIME = "15"
 DEFAULT_DURATION = "600"
 
+DEFAULT_RETRY_MAX = 0
+DEFAULT_RETRY_WAIT = 0
+
 
 
 def setup_logging(log_file):
@@ -153,7 +156,7 @@ def run_benchmarks(api_client, assets, base_job, fio_bin, block_sizes, depths, m
     for i, (bs, depth, mode) in enumerate(itertools.product(block_sizes, depths, modes)):
         logger.info("Launching job. Block Size:%s, I/O Depth:%s, I/O Mode:%s", bs, depth, mode)
 
-        job = base_job + Job({
+        job = base_job + BASE_BENCH_JOB + Job({
             "bs": bs,
             "iodepth": depth,
             "rw": mode,
@@ -184,10 +187,9 @@ def start_benchmark(cloud, api_client, benchmark_volumes, fio_bin,  block_sizes,
     # Prepare jobs
     base_job = BASE_LINUX_JOB + Job({
         "filename": ":".join(vol.device for vol in benchmark_volumes),
-        "time_based": None,
         "ramp_time": ramp,
         "runtime": duration,
-        })
+    })
 
     # Warm up the disk
     logger.debug("Running warm-up job")
@@ -217,7 +219,9 @@ def main():
         "nobench": "",
         "size": DEFAULT_FILE_SIZE,
         "ramp": DEFAULT_RAMP_TIME,
-        "duration": DEFAULT_DURATION
+        "duration": DEFAULT_DURATION,
+        "retry_max": DEFAULT_RETRY_MAX,
+        "retry_wait": DEFAULT_RETRY_WAIT,
     })
     config.add_section("environment")
     config.add_section("general")
@@ -241,6 +245,8 @@ def main():
     reporting_endpoint = config.get("reporting", "endpoint")
     reporting_username = config.get("reporting", "username")
     reporting_key = config.get("reporting", "apikey")
+    reporting_retry_max = config.get("reporting", "retry_max")
+    reporting_retry_wait = config.get("reporting", "retry_wait")
 
     #TODO: Retries
 
@@ -249,7 +255,8 @@ def main():
     cloud = Cloud()
     benchmark_volumes = identify_benchmark_volumes(cloud, no_bench)
 
-    api = Client(reporting_endpoint, APIKeyAuth(reporting_username, reporting_key))
+    api = Client(reporting_endpoint, APIKeyAuth(reporting_username, reporting_key),
+                 reporting_retry_max, reporting_retry_wait)
 
     logger.info("Provider: %s", cloud.provider)
     logger.info("Location: %s", cloud.location)
